@@ -2241,7 +2241,8 @@ def loadConfig(module=None):
             slot_dict[slot.name] = slot
         return slot_dict
     except (ImportError, AttributeError, TypeError):
-        pass
+        import traceback
+        traceback.print_exc()
     sys.path = orig_path
 
     logging.warning('using implicit configuration')
