@@ -100,7 +100,7 @@ def _list_ssh(url):
     '''
     host, path = url.split(':', 1)
     proc = Popen(['ssh', host, 'ls -a1 %r' % path], stdout=PIPE)
-    return proc.communicate()[0].splitlines()
+    return proc.communicate()[0].decode().splitlines()
 
 
 def _url_protocol(url):
@@ -620,7 +620,7 @@ class Script(PlainScript):
                 command = ['patch', '-p1', '-f', '-i', 'slot.patch']
                 proc = Popen(command, cwd=dest, stdout=PIPE, stderr=STDOUT)
                 out, _ = proc.communicate()
-                self.log.debug('output of %s:\n%s', command, out)
+                self.log.debug('output of %s:\n%s', command, out.decode())
 
             if index_installed:
                 fixGlimpseIndexes(
