@@ -471,6 +471,7 @@ def createManifestFile(project, version, platform, build_dir):
                  stdout=PIPE,
                  stderr=PIPE)
     out, _err = proc.communicate()
+    out = out.decode()
 
     # no check because we must have a dependency on LCGCMT
     match = re.search(r'LCGCMT_([^ ]+)', out)
@@ -501,7 +502,7 @@ def createManifestFile(project, version, platform, build_dir):
                      stdout=PIPE,
                      stderr=PIPE)
         out, _err = proc.communicate()
-        out = out.splitlines()
+        out = out.decode().splitlines()
         data_pkgs = [
             x.replace(' ', ',').split(',')[1:4:2] for x in out
             if re.search(r'DBASE|PARAM', x)
