@@ -151,7 +151,7 @@ def tee_call(*args, **kwargs):
                     close_unregister_and_remove(fd)
         retcode = proc.wait()
 
-    return retcode, ''.join(out), ''.join(err)
+    return retcode, b''.join(out), b''.join(err)
 
 
 def log_call(*args, **kwargs):
@@ -206,7 +206,7 @@ def log_call(*args, **kwargs):
     if proc.stderr:
         output[proc.stderr.fileno()] = err
     spilled_output = dict(
-        (x.fileno(), '') for x in (proc.stdout, proc.stderr) if x)
+        (x.fileno(), b'') for x in (proc.stdout, proc.stderr) if x)
 
     poller.register(proc.stdout, select_POLLIN_POLLPRI)
     if proc.stderr:
@@ -231,10 +231,10 @@ def log_call(*args, **kwargs):
                     close_unregister_and_remove(fd)
                 output[fd].append(data)
                 data = spilled_output[fd] + data
-                spilled_output[fd] = ''
+                spilled_output[fd] = b''
                 for line in data.splitlines(True):
-                    if line.endswith('\n'):
-                        log(log_level, line.rstrip())
+                    if line.endswith(b'\n'):
+                        log(log_level, line.decode().rstrip())
                     else:
                         spilled_output[fd] += line
             else:
@@ -242,7 +242,11 @@ def log_call(*args, **kwargs):
                 close_unregister_and_remove(fd)
     retcode = proc.wait()
 
-    return {'retcode': retcode, 'stdout': ''.join(out), 'stderr': ''.join(err)}
+    return {
+        'retcode': retcode,
+        'stdout': b''.join(out),
+        'stderr': b''.join(err)
+    }
 
 
 def _retry_wrapper(func, check=None):
@@ -1163,9 +1167,9 @@ def gitlabProjectExists(project):
 
 MR_COMMENT_TMPLS = {
     True: ('Validation started with [{slot}#{id}]('
-           'https://lhcb-nightlies.cern.ch/nightly/{slot}/build/{id}/)'),
+           'https://lhcb-nightlies.web.cern.ch/nightly/{slot}/build/{id}/)'),
     False: ('Automatic merge failed in [{slot}#{id}]('
-            'https://lhcb-nightlies.cern.ch/logs/checkout/nightly/'
+            'https://lhcb-nightlies.web.cern.ch/logs/checkout/nightly/'
             '{slot}/{id}/{proj}/)'),
 }
 
